-- settings lua

settings = gamestate:new()

function settings:enter()

	menuItem:init()
	world:init()
	world:changeMap( "settingsbackground" )
	
	local items = { "Scale", "Fullscreen", "Fancy Lighting", "Volume", "Back" }
	for i = 1, #items do
		menuItem:new( items[i], width / 2, height / 3 + 50 * i )
	end

end

function settings:leave()

	soundmanager:init()
	menuItem:init() -- delete the old menuItems

end

function settings:update( dt )

	menuItem:update( dt )
	world:update( dt )

end

function settings:draw()

	local g = love.graphics

	world:draw()
	g.draw( menu.vignette, 0, 0 )
	
	g.printf( "".. tostring( scale ), width / 2 - 50, height / 3 + 50 * 1 + g.getFont():getHeight(), 100, "center" )
	g.printf( "".. tostring( fullscreen ), width / 2 - 50, height / 3 + 50 * 2 + g.getFont():getHeight(), 100, "center" )
	g.printf( "".. tostring( fancylighting ), width / 2 - 50, height / 3 + 50 * 3 + g.getFont():getHeight(), 100, "center" )
	g.printf( "".. tostring( volume ), width / 2 - 50, height / 3 + 50 * 4 + g.getFont():getHeight(), 100, "center" )
	
	g.setFont( font_xl )
	g.setColor( 255, 255, 255 )
	g.printf( " Settings ", width / 2 - 100, 20, 200, "center" )
	
	menuItem:draw()
	
end

function settings:keypressed( key )

	if key == "right" then
	
		if menuItem:current( "Fullscreen" ) then 
			fullscreen = not fullscreen
			love.graphics.setMode( width * scale, height * scale, fullscreen, vsync, 0 )
			world:setCanvas()
		elseif menuItem:current( "Scale" ) and scale < 2 then 
			scale = scale + .5
			love.graphics.setMode( width * scale, height * scale, fullscreen, vsync, 0 )
			world:setCanvas()
		elseif menuItem:current( "Fancy Lighting" ) then fancylighting = not fancylighting
		elseif menuItem:current( "Volume" ) and volume < 100 then
			s_hurt:play()
			volume = volume + 10
		end

	elseif key == "left" then
		
		if menuItem:current( "Fullscreen" )	then 
			fullscreen = not fullscreen
			love.graphics.setMode( width * scale, height * scale, fullscreen, vsync, 0 )
			world:setCanvas()
		elseif menuItem:current( "Scale" ) and scale > 1 then
			scale = scale - .5
			love.graphics.setMode( width * scale, height * scale, fullscreen, vsync, 0 )
			world:setCanvas()
		elseif menuItem:current( "Fancy Lighting" ) then fancylighting = not fancylighting
		elseif menuItem:current( "Volume" ) and volume > 0 then
			s_hurt:play()
			volume = volume - 10
		end
		
	elseif key == "return" then
		if menuItem:current( "Back" ) then fader:fadeTo( menu )
		end
		s_enter:play()
	elseif key == "escape" then fader:fadeTo( menu )
	end
	
	menuItem:keypressed( key )

end

function settings:mousepressed( x, y, b )

	if b == "l" and menuItem.lastitem ~= 0 then
		if menuItem:current( "Scale" ) then
			if scale < 2 then
				scale = scale + .5
			else 
				scale = 1
			end
			love.graphics.setMode( width * scale, height * scale, fullscreen, vsync, 0 )
			world:setCanvas()
		elseif menuItem:current( "Fullscreen" ) then 
			fullscreen = not fullscreen
			love.graphics.setMode( width * scale, height * scale, fullscreen, vsync, 0 )
			world:setCanvas()
		elseif menuItem:current( "Fancy Lighting" ) then 
			fancylighting = not fancylighting
		elseif menuItem:current( "Volume" ) then
			if volume < 100 then
				volume = volume + 10
			else 
				volume = 0
			end
		elseif menuItem:current( "Back" ) then fader:fadeTo( menu )
		end
	end	

end