-- player lua

player = class:new()

function player:init()

	local g = love.graphics

	self.x, self.y = 0, 0
	self.w, self.h = 16, 16
	self.sx, self.sy = 2, 2
	self.xSpeed = 220
	self.xvel, self.yvel = self.xSpeed, 0
	self.inAir = false
	self.floor = 0
	self.dead = false
	self.waitTime = 1.5
	self.timer = 0
	self.spawnAlpha = 30
	self.health = 100
	self.actionTimer = 0

-- animations
	self.anim_idle = newAnimation( g.newImage( "gfx/game/p_idle.png" ), self.w, self.h, .15, 0 )
	self.anim_walkleft = newAnimation( g.newImage( "gfx/game/p_walkleft.png" ), self.w, self.h, .1, 0 )
	self.anim_walkright = newAnimation( g.newImage( "gfx/game/p_walkright.png" ), self.w, self.h, .1, 0 )
	self.anim_jump = newAnimation( g.newImage( "gfx/game/p_jump.png" ), self.w, self.h, .2, 0 )
	self.anim_jump:stop()

end

function player:setPosition( x, y )
	self.x, self.y = x, y
end

function player:applyDamage( value )
	player.health = player.health - value
end

function player:update( dt )

	local leaveMap = self.x > map.width - 2
	local k = love.keyboard
	local left, right = k.isDown( "left", "a" ), k.isDown( "right", "d" )
	local m = map
	local g = love.graphics

-- update values
	self.actionAvailable = false
	self.hitbox = { x = self.x + 2, y = self.y, w = self.w * self.sx - 4, h = self.h * self.sy }
	self.x = self.x + ( self.xvel + conveyor.extraSpeed ) * dt
	self.xvel = 0
	
	if not self.dead and not leaveMap then
-- Move left / right
	if left and not right then 
		self.xvel = -self.xSpeed
	elseif right and not left then 
		self.xvel = self.xSpeed
	end
	
-- Jump animation left / right
	if self.yvel ~= 0 then
		if left and not right then
			self.anim_jump:seek( 3 )
		elseif right and not left then
			self.anim_jump:seek( 4 )
		end
	end

-- Jump animation up / down
	if self.yvel < 0 and not( left or right ) then
		self.anim_jump:seek( 1 )
	elseif self.yvel > 0 and not( left or right ) then
		self.anim_jump:seek( 2 )
	end
	
-- set the camera to the player
	camera.x = camera.x - (camera.x - (player.x - width / 2 + (player.w / 2))) * dt * camera.speed
	camera.y = camera.y - (camera.y - (player.y - height / 2 + (player.h / 2))) * dt * camera.speed

	if camera.x < 0 then camera.x = 0
	elseif camera.x + width > map.width then camera.x = map.width - width
	end
	
	if camera.y < 0 then camera.y = 0
	elseif camera.y + height > map.height then camera.y = map.height - height
	end	
	
	self.spotX, self.spotY = player.x - camera.x, player.y - camera.y
		
	end

-- Shitty collision detection, SORRY! I had thought about collision earlier
	for i,v in ipairs( m ) do
		local above, under = self.y + self.h < v.y, self.y < v.y + tile.size
		local tilebottom = self.y < v.y + tile.size - 8
			if boxCollide( self.hitbox, { x = v.x, y = v.y, w = tile.size, h = tile.size } ) then
				if ( v.Type == 3 or v.Type == 7 or v.Type == 8 ) and above and self.yvel >= 0 then
					self.floor = v.y
				elseif (v.Type == 5 or v.Type == 7) and not left then
					self.x = self.x - ( self.xvel + conveyor.extraSpeed ) * dt
				elseif (v.Type == 6 or v.Type == 8) and not right then
					self.x = self.x - self.xvel * dt
				elseif v.Type == 4 and not right then 
					self.x = self.x - self.xvel * dt
				elseif v.Type == 2 and not left then 
					self.x = self.x - self.xvel * dt
				end
				if ( v.Type == 1 or v.Type == 5 or v.Type == 6 ) and under and not tilebottom and self.yvel < 0 then
					self.yvel = 1
				end
			end
	end
	
-- player jump
	local frame = dt * 30 
	if not leaveMap then
		self.yvel = self.yvel + ( game.grav * frame )
		self.y = self.y + ( self.yvel * frame )
		if self.y > self.floor - self.h * self.sy then 
			self.y = self.floor - self.h * self.sy
			self.yvel = 0 
			self.inAir = false
		end
	end
	
-- limit the fallspeed
	if self.yvel > 22 then self.yvel = 22 end
	
-- resets the floor if no tile is there
	self.floor = map.height
	
-- update the animations
	self.anim_jump:update( dt )
	self.anim_idle:update( dt )
	self.anim_walkleft:update( dt )
	self.anim_walkright:update( dt )
	
-- Level finished -> switch to next one
	if leaveMap then
		fader:fadeTo( function() world:changeMap( world:nextMap() ) end )
	end
	
-- what happen if the entity dies / get destroyed
	if self.health <= 0 then
	
		if self.timer < self.waitTime then
			self.timer = self.timer + dt
		end
		
		if self.x ~= map.spawnX then
			self:setPosition( world:getSpawn() )
			self.dead = true
			
			game:slowmotion( 1 )
			s_dead:play()	
		end
		
	-- wait time over => spawn player
		if self.timer >= self.waitTime then
			self.health = 100
			game.deathcount = game.deathcount + 1
			self.dead = false
			self.timer = 0
			self.spawnAlpha = 30
			spikepad:reset()
		end
	end
	
-- Update the spawn effect
	if self.spawnAlpha > 0 then
		self.spawnAlpha = self.spawnAlpha - 60 * dt
	end
	
end

function player:draw()

	local g = love.graphics
	local action = self.actionAvailable
	local k = love.keyboard
	
	if not self.dead then
		local left, right = k.isDown( "left", "a" ), k.isDown( "right", "d" )
	-- draw the animations
		g.setColor( 255, 255, 255 )
		if ( not left and not right or left and right ) and not self.inAir then
			self.anim_idle:draw( self.x, self.y, 0, self.sx, self.sy )
		elseif left and not self.inAir then
			self.anim_walkleft:draw( self.x, self.y, 0, self.sx, self.sy )
		elseif right and not self.inAir then
			self.anim_walkright:draw( self.x, self.y, 0, self.sx, self.sy )
		else
			self.anim_jump:draw( self.x, self.y, 0, self.sx, self.sy )
		end
	end
	
-- shows the "action" text
	if action then
		self.actionTimer = self.actionTimer + love.timer.getDelta()
		g.setColor( 255, 255, 255, 25 )
		g.setFont( font_small )
		g.printf( "Action", self.x - 35, self.y - 25 + self.y * math.sin( self.actionTimer * 2.5 ) / 175, 100, "center" )
	end
	
-- draws the spawn effect
	if self.spawnAlpha > 0 then
		g.setColor( 255, 255, 255, self.spawnAlpha )
		g.rectangle( "fill", self.x, 0 , tile.size, map.height - ( map.height - self.y - tile.size ) )
	end
	
end

function player:keypressed( key )

-- Jump
	if ( key == "w" or key == "up" or key == " " ) and not self.inAir and not self.dead and not pause then 
		self.yvel = -19
		s_jump:play()
		self.inAir = true
	elseif key == "r" and not pause then
		self:setPosition( world:getSpawn() )
	end

end